ValueRange
==========

.. currentmodule:: pykeen.metrics

.. autoclass:: ValueRange
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ValueRange.lower
      ~ValueRange.lower_inclusive
      ~ValueRange.upper
      ~ValueRange.upper_inclusive

   .. rubric:: Methods Summary

   .. autosummary::

      ~ValueRange.approximate
      ~ValueRange.notate

   .. rubric:: Attributes Documentation

   .. autoattribute:: lower
   .. autoattribute:: lower_inclusive
   .. autoattribute:: upper
   .. autoattribute:: upper_inclusive

   .. rubric:: Methods Documentation

   .. automethod:: approximate
   .. automethod:: notate
